==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggframedoublebutton.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGFRAMEDOUBLEBUTTON_H
#define IGGFRAMEDOUBLEBUTTON_H


#include "iggframe.h"


class iObjectType;
class iPosition;
class iString;


class iggFrameDoubleButton : public iggFrame
{

public:

	virtual ~iggFrameDoubleButton(){}

	virtual void OnButton1() = 0;
	virtual void OnButton2() = 0;

protected:

	iggFrameDoubleButton(iggFrame *parent, int cols);
	iggFrameDoubleButton(const iString &title, iggFrame *parent, int cols);
};


class iggFrameCreateDeleteButton : public iggFrameDoubleButton
{

public:

	iggFrameCreateDeleteButton(iggFrame *dependent, const iObjectType &type, bool keeplast, const iString &name, iggFrame *parent);
	
	void SetActive(bool s);

protected:

	virtual bool UpdateWidgetBody();
	virtual void OnButton1();
	virtual void OnButton2();

	bool mKeepLast, mActive;
	iggWidget *mDeleteButton;
	const iObjectType &mType;
	iggFrame *mDependent;
};


class iggFrameMoveFocalPointButton : public iggFrameDoubleButton
{

public:

	iggFrameMoveFocalPointButton(iggFrame *parent, bool withmarker = false);
	iggFrameMoveFocalPointButton(const iString &title, iggFrame *parent, bool withmarker = false);

	virtual void GetPosition(double x[3]) const = 0;
	virtual int GetWindowNumber() const { return -1; }

	void SetMoveInstantly(bool s);
	inline bool GetMoveInstantly() const { return mMoveInstantly; }

protected:

	virtual void OnButton1();
	virtual void OnButton2();

	bool mMoveInstantly;

private:

	void Define(bool withmarker);
};

#endif  // IGGFRAMEDOUBLEBUTTON_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggframedoublebutton.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGFRAMEDOUBLEBUTTON_H
#define IGGFRAMEDOUBLEBUTTON_H


#include "iggframe.h"


class iObjectType;
class iPosition;
class iString;


class iggFrameDoubleButton : public iggFrame
{

public:

	virtual ~iggFrameDoubleButton(){}

	virtual void OnButton1() = 0;
	virtual void OnButton2() = 0;

protected:

	iggFrameDoubleButton(iggFrame *parent, int cols);
	iggFrameDoubleButton(const iString &title, iggFrame *parent, int cols);
};


class iggFrameCreateDeleteButton : public iggFrameDoubleButton
{

public:

	iggFrameCreateDeleteButton(iggFrame *dependent, const iObjectType &type, bool keeplast, const iString &name, iggFrame *parent);
	
	void SetActive(bool s);

protected:

	virtual void UpdateWidgetBody();
	virtual void OnButton1();
	virtual void OnButton2();

	bool mKeepLast, mActive;
	iggWidget *mDeleteButton;
	const iObjectType &mType;
	iggFrame *mDependent;
};


class iggFrameMoveFocalPointButton : public iggFrameDoubleButton
{

public:

	iggFrameMoveFocalPointButton(iggFrame *parent, bool withmarker = false);
	iggFrameMoveFocalPointButton(const iString &title, iggFrame *parent, bool withmarker = false);

	virtual void GetPosition(double x[3]) const = 0;
	virtual int GetWindowNumber() const { return -1; }

	void SetMoveInstantly(bool s);
	inline bool GetMoveInstantly() const { return mMoveInstantly; }

protected:

	virtual void OnButton1();
	virtual void OnButton2();

	bool mMoveInstantly;

private:

	void Define(bool withmarker);
};

#endif  // IGGFRAMEDOUBLEBUTTON_H
